# Project Tests

Your project's tests go in this directory.

- Each file should be named `test_<module-name>.py`.
- Write tests using unittest.
- If property tests are useful for the project, use Hypothesis.

## Running All Tests

Navigate to the root directory and run the following command

```bash 
python -m unittest discover -s tests
```
